//-- Data: 26/11/2008 
//-- Autor: Jesiel Spzak Campos

using System;
using System.Collections;
using System.Data;
using System.Data.SqlClient;

namespace DcartesClassLibrary
{
	public partial class DashBoard // Tabela: DashBoard
	{
		#region Atributos
		private int codigoDashBoard;
        private int codigoLoj;
		private char funcao;
		private DateTime dtaInicial;
        private DateTime dtaFinal;
		private double? vlrMin;
        private double? vlrMax;
		private char periodicidade;
		private string tipoGrafico;
		#endregion

		#region Propriedades
        public int CodigoDashBoard
        {
            get { return this.codigoDashBoard; }
            set { this.codigoDashBoard = value; }
        }
        public int CodigoLoj
        {
            get { return this.codigoLoj; }
            set { this.codigoLoj = value; }
        }
        public char Funcao
        {
            get { return this.funcao; }
            set { this.funcao = value; }
        }
        public DateTime DtaInicial
        {
            get { return this.dtaInicial; }
            set { this.dtaInicial = value; }
        }
        public DateTime DtaFinal
        {
            get { return this.dtaFinal; }
            set { this.dtaFinal = value; }
        }
        public double? VlrMin
        {
            get { return this.vlrMin; }
            set { this.vlrMin = value; }
        }
        public double? VlrMax
        {
            get { return this.vlrMax; }
            set { this.vlrMax = value; }
        }
        public char Periodicidade
        {
            get { return this.periodicidade; }
            set { this.periodicidade = value; }
        }
        public string TipoGrafico
        {
            get { return this.tipoGrafico; }
            set { this.tipoGrafico = value; }
        }
		#endregion

		#region Construtores
		public DashBoard()
			: this(-1)
		{ }
		public DashBoard(int codigo)
		{
			this.codigoDashBoard = codigo;
		}
		#endregion

		#region Constantes

		#region StoredProcedures
		private const string SPINSERT = "spDashBoardIns";
		private const string SPUPDATE = "spDashBoardUpd";
		private const string SPDELETE = "spDashBoardDel";
		private const string SPSELECT = "spDashBoardSel";
		private const string SPSELECTcodigoDashBoard = "spDashBoardSelId";
		#endregion

		#region Parametros SQL
		private const string PARMCODIGO = "@codigoDashBoard";
		#endregion

		#endregion

		#region Métodos Nativos

		#region GetParameters
		private SqlParameter[] GetParameters()
		{
			SqlParameter[] parms;
			//Tentando buscar os parâmetros do cache
			parms = DataBase.GetCachedParameters(SPINSERT);
			if (parms == null)
			{
				parms = new SqlParameter[] {
					/*0*/ new SqlParameter(PARMCODIGO, SqlDbType.Int),
					/*1*/ new SqlParameter("@codigoLoj", SqlDbType.Int),
					/*2*/ new SqlParameter("@funcao", SqlDbType.Char),
					/*3*/ new SqlParameter("@vlrMin", SqlDbType.Money),
                    /*4*/ new SqlParameter("@vlrMax", SqlDbType.Money),
					/*5*/ new SqlParameter("@dtaInicial", SqlDbType.DateTime),
                    /*6*/ new SqlParameter("@dtaFinal", SqlDbType.DateTime),
					/*7*/ new SqlParameter("@periodiCidade", SqlDbType.Char),
                    /*8*/ new SqlParameter("@tipoGrafico", SqlDbType.VarChar)
				};

				//Criando cache dos parâmetros
				DataBase.CacheParameters(SPINSERT, parms);
			}
			return(parms);
		}
		#endregion

		#region SetParameters
		private void SetParameters(SqlParameter[] parms)
		{
			parms[0].Value = this.codigoDashBoard;
            parms[1].Value = this.codigoLoj;
            parms[2].Value = this.funcao;
			if (this.vlrMin != null)
				parms[3].Value = this.vlrMin;
			else
				parms[3].Value = DBNull.Value;
            
            if (this.vlrMax != null)
				parms[4].Value = this.vlrMax;
			else
				parms[4].Value = DBNull.Value;
            parms[5].Value = this.dtaInicial;
            parms[6].Value = this.dtaFinal;
            parms[7].Value = this.periodicidade;
			parms[8].Value = this.tipoGrafico;
            
			if (this.codigoDashBoard <= 0)
				parms[0].Direction = ParameterDirection.Output;
			else
				parms[0].Direction = ParameterDirection.Input;
		}
		#endregion

		#region Insert

		/// <summary>
		/// Insert com tratamento de transação
		/// </summary>
		private void Insert()
		{
			SqlParameter[] parms = GetParameters();
			SetParameters(parms);

			using (SqlConnection conn = new SqlConnection(DataBase.CONN_STRING))
			{
				conn.Open();
				using (SqlTransaction trans = conn.BeginTransaction())
				{
					try
					{
						SqlCommand cmd = DataBase.ExecuteNonQueryCmd(trans, CommandType.StoredProcedure, SPINSERT, parms);
						//Obtendo a chave de identificação do registro inserido.
						this.CodigoDashBoard = Convert.ToInt32(cmd.Parameters[PARMCODIGO].Value);
						cmd.Parameters.Clear();
						trans.Commit();
					}
					catch (Exception ex)
					{
						trans.Rollback();
						throw (ex);
					}
				}
			}
		}

		/// <summary>
		/// Insert sem tratamento de transação
		/// </summary>
		/// <param name="trans">SqlTransaction</param>
		private void Insert(SqlTransaction trans)
		{
			SqlParameter[] parms = GetParameters();
			SetParameters(parms);
			try
			{
				SqlCommand cmd = DataBase.ExecuteNonQueryCmd(trans, CommandType.StoredProcedure, SPINSERT, parms);
				//Obtendo a chave de identificação do registro inserido.
				this.codigoDashBoard = Convert.ToInt32(cmd.Parameters[PARMCODIGO].Value);
				cmd.Parameters.Clear();
			}
			catch (Exception ex)
			{
				throw (ex);
			}
		}

		#endregion

		#region Update

		/// <summary>
		/// Update com tratamento de transação
		/// </summary>
		private void Update()
		{
			SqlParameter[] parms = GetParameters();
			SetParameters(parms);

			using (SqlConnection conn = new SqlConnection(DataBase.CONN_STRING))
			{
				conn.Open();
				using (SqlTransaction trans = conn.BeginTransaction())
				{
					try
					{
						DataBase.ExecuteNonQuery(trans, CommandType.StoredProcedure, SPUPDATE, parms);
						trans.Commit();
					}
					catch (Exception ex)
					{
						trans.Rollback();
						throw (ex);
					}
				}
			}
		}

		/// <summary>
		/// Update sem tratamento de transação
		/// </summary>
		private void Update(SqlTransaction trans)
		{
			SqlParameter[] parms = GetParameters();
			SetParameters(parms);

			try
			{
				DataBase.ExecuteNonQuery(trans, CommandType.StoredProcedure, SPUPDATE, parms);
			}
			catch (Exception ex)
			{
				throw (ex);
			}
		}
		#endregion

		#region Save

		/// <summary>
		/// Save com tratamento de transação
		/// </summary>
		public void Save()
		{
			if (this.codigoDashBoard <= 0)
				this.Insert();
			else
				this.Update();
		}

		/// <summary>
		/// Save sem tratamento de transação
		/// </summary>
		public void Save(SqlTransaction trans)
		{
			if (this.codigoDashBoard <= 0)
				this.Insert(trans);
			else
				this.Update(trans);
		}

		#endregion

		#region Delete

		/// <summary>
		/// Delete com tratamento de transação
		/// </summary>
		/// <param name="codigo">Código do Registro</param>
		public static void Delete(int codigo)
		{
			SqlParameter[] parms = new SqlParameter[] { new SqlParameter(PARMCODIGO, SqlDbType.Int, 4) };
			parms[0].Value = codigo;
			using (SqlConnection conn = new SqlConnection(DataBase.CONN_STRING))
			{
				conn.Open();
				using (SqlTransaction trans = conn.BeginTransaction())
				{
					try
					{
						DataBase.ExecuteNonQuery(CommandType.StoredProcedure, SPDELETE, parms);
						trans.Commit();
					}
					catch (Exception ex)
					{
						trans.Rollback();
						throw (ex);
					}
				}
			}
		}

		/// <summary>
		/// Delete sem tratamento de transação
		/// </summary>
		/// <param name="codigo">Código do Registro</param>
		/// <param name="trans">SqlTransaction</param>
		public static void Delete(int codigo, SqlTransaction trans)
		{
			SqlParameter[] parms = new SqlParameter[] { new SqlParameter(PARMCODIGO, SqlDbType.Int, 4) };
			parms[0].Value = codigo;
			try
			{
				DataBase.ExecuteNonQuery(trans, CommandType.StoredProcedure, SPDELETE, parms);
			}
			catch (Exception ex)
			{
				throw (ex);
			}
		}

		#endregion

		#region LoadDataReader

		/// <summary>
		/// LoadDataReader
		/// </summary>
		/// <returns>DataReader</returns>
		private static SqlDataReader LoadDataReader()
		{
			SqlParameter[] parms = new SqlParameter[] { new SqlParameter(PARMCODIGO, SqlDbType.Int, 4) };
			parms[0].Value = null;
			SqlDataReader dr = DataBase.ExecuteReader(CommandType.StoredProcedure, SPSELECT, parms);
			return dr;
		}

		/// <summary>
		/// LoadDataReader
		/// </summary>
		/// <param name="codigo">Código do Registro</param>
		/// <returns>DataReader</returns>
		public static SqlDataReader LoadDataReader(int codigo)
		{
			SqlParameter[] parms = new SqlParameter[] { new SqlParameter(PARMCODIGO, SqlDbType.Int, 4) };
			parms[0].Value = codigo;
			SqlDataReader dr = DataBase.ExecuteReader(CommandType.StoredProcedure, SPSELECTcodigoDashBoard, parms);
			return dr;
		}

		/// <summary>
		/// LoadDataReader para ser utilizando dentro de alguma transação
		/// </summary>
		/// <param name="codigo">Código do Registro</param>
		/// <param name="trans">SqlTransaction</param>
		/// <returns>DataReader</returns>
		private static SqlDataReader LoadDataReader(int codigo, SqlTransaction trans)
		{
			SqlParameter[] parms = new SqlParameter[] { new SqlParameter(PARMCODIGO, SqlDbType.Int, 4) };
			parms[0].Value = codigo;
			SqlDataReader dr = DataBase.ExecuteReader(trans, CommandType.StoredProcedure, SPSELECTcodigoDashBoard, parms);
			return dr;
		}

		#endregion

		#region LoadObject

		/// <summary>
		/// LoadObject
		/// </summary>
		/// <param name="codigo">Código do Registro</param>
		/// <returns>DashBoard</returns>
		public static DashBoard LoadObject(int codigo)
		{
			SqlDataReader dr = LoadDataReader(codigo);
			DashBoard dashBoard = new DashBoard();
			try
			{
                SetInstance(dr, dashBoard);
			}
			catch (Exception ex)
			{
				throw (ex);
			}
            return dashBoard;
		}

		/// <summary>
		/// LoadObject para ser utilizado dentro de alguma transação
		/// </summary>
		/// <param name="codigo">Código do Registro</param>
		/// <param name="trans">SqlTransaction</param>
		/// <returns>DashBoard</returns>
		public static DashBoard LoadObject(int codigo, SqlTransaction trans)
		{
			SqlDataReader dr = LoadDataReader(codigo, trans);
			DashBoard consumidor = new DashBoard();
			try
			{
				SetInstance(dr, consumidor);
			}
			catch (Exception ex)
			{
				throw (ex);
			}
			return consumidor;
		}

		#endregion

		#region LoadDashBoard

		/// <summary>
		/// LoadDashBoard
		/// </summary>
		public void LoadDashBoard()
		{
			SqlDataReader dr = LoadDataReader(this.codigoDashBoard);
			try
			{
				SetInstance(dr, this);
			}
			catch (Exception ex)
			{
				throw (ex);
			}
		}

		/// <summary>
		/// LoadDashBoard para ser utilizado dentro de alguma transação
		/// </summary>
		/// <param name="trans">SqlTransaction</param>
		public void LoadDashBoard(SqlTransaction trans)
		{
			SqlDataReader dr = LoadDataReader(this.codigoDashBoard, trans);
			try
			{
				SetInstance(dr, this);
			}
			catch (Exception ex)
			{
				throw (ex);
			}
		}

		#endregion

		#region SetInstance
		private static void SetInstance(SqlDataReader dr, DashBoard dashBord)
		{
			try
			{
				if (dr.Read())
				{
					dashBord.codigoDashBoard = Convert.ToInt32(dr["codigoCon"]);
					dashBord.codigoLoj = Convert.ToInt32(dr["codigoLoj"]);
					dashBord.funcao = Convert.ToChar(dr["funcao"]);
                    if (Convert.ToString(dr["vlrMin"]) != "")
					    dashBord.vlrMin = Convert.ToDouble(dr["vlrMin"]);
                    if (Convert.ToString(dr["vlrMax"]) != "")
                        dashBord.vlrMax = Convert.ToDouble(dr["vlrMax"]);
                    dashBord.dtaInicial = Convert.ToDateTime(dr["dtaInicial"]);
                    dashBord.dtaFinal = Convert.ToDateTime(dr["dtaFinal"]);
                    dashBord.periodicidade = Convert.ToChar(dr["periodiCidade"]);
                    dashBord.tipoGrafico = Convert.ToString(dr["tipoGrafico"]);
				}
			}
			catch (Exception ex)
			{
				if (!dr.IsClosed)
					dr.Close();
				dashBord = new DashBoard();
				throw (ex);
			}
			finally
			{
				if (!dr.IsClosed)
					dr.Close();
			}
		}
		#endregion

        #endregion

        #region Métodos Auxiliares

        #region Meta
        public static string Meta(DateTime de, DateTime ate, int Codloja)
        {
            string retorno = "1";
            SqlParameter[] param = new SqlParameter[] { new SqlParameter("@dtaDe", SqlDbType.DateTime),
                                                        new SqlParameter("@dtaAte", SqlDbType.DateTime),
                                                        new SqlParameter("@CodLoja", SqlDbType.Int)};
            param[0].Value = de;
            param[1].Value = ate;
            param[2].Value = Codloja;
            SqlDataReader dr = DataBase.ExecuteReader(CommandType.StoredProcedure, "spMetaSel", param);
            if (dr.Read())
            {
                retorno = dr["valor"].ToString();
            }
            dr.Close();
            retorno = Convert.ToDecimal(retorno).ToString("n2").Replace(",", "").Replace(".", "");
            return retorno;
        }
        #endregion

        #region TicketMedio
        /// <summary>
        /// TicketMedio
        /// </summary>
        /// <param name="de"></param>
        /// <param name="ate"></param>
        /// <param name="tipo">A - Anual, D - Diario, M - Mênsal</param>
        /// <returns></returns>
        public static SqlDataReader TicketMedio(DateTime de, DateTime ate, string tipo,int codLoja)
        {
            SqlParameter[] param = new SqlParameter[] { new SqlParameter("@dtaDe", SqlDbType.DateTime),
                                                        new SqlParameter("@dtaAte", SqlDbType.DateTime),
                                                        new SqlParameter("@tipo", SqlDbType.VarChar, 1),
                                                        new SqlParameter("@codLoja", SqlDbType.Int)};
            param[0].Value = de;
            param[1].Value = ate;
            param[2].Value = tipo;
            param[3].Value = codLoja;
            SqlDataReader dr = DataBase.ExecuteReader(CommandType.StoredProcedure, "spTicketMedioSel", param);
            return dr;
        }
        #endregion

        #region LoadDataReaderLoja
        /// <summary>
        /// LoadDataReaderLoja
        /// </summary>
        /// <param name="codigo">Código da Loja</param>
        /// <returns>DataReader</returns>
        public static SqlDataReader LoadDataReaderLoja(int codigo)
        {
            SqlParameter[] parms = new SqlParameter[] { new SqlParameter("@codigoLoj", SqlDbType.Int, 4) };
            parms[0].Value = codigo;
            SqlDataReader dr = DataBase.ExecuteReader(CommandType.StoredProcedure, SPSELECT, parms);
            return dr;
        }
        #endregion

        #endregion
    }
}