using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

/// <summary>
/// Summary description for JavaScripts
/// </summary>
public static class JavaScripts
{
    #region jsFormataStr
    /// <summary>
    /// funo para contar os caracteres
    /// </summary>
    /// <returns></returns>
    public static string jsFormataStr()
    {
        /// c_str = string que vai ser contada
        /// tam = tamanho maximo
        /// textocont = texto do contador do label
        return @"function FormataStr(c_str, tam, textocont){
	                var str_tam = c_str.value.substr(0,tam);
	                var c_str_tam= c_str.value.length;
                	
	                if (c_str_tam > tam){
		                alert('Campo limitado em '+tam+' caracteres.');
		                c_str.value = str_tam;
		                textocont.innerText = 0;
	                }
	                else
	                    textocont.innerText = tam-c_str_tam;	
                }";
    }
    #endregion

    #region jsValidaCPFCNPJ
    public static string jsValidaCPFCNPJ()
    {
        return @"
        var NUM_DIGITOS_CPF  = 11;
        var NUM_DIGITOS_CNPJ = 14;
        var NUM_DGT_CNPJ_BASE = 8;
        /**
         * Adiciona mtodo lpad()  classe String.
         * Preenche a String  esquerda com o caractere fornecido,
         * at que ela atinja o tamanho especificado.
         */
        String.prototype.lpad = function(pSize, pCharPad)
        {
	        var str = this;
	        var dif = pSize - str.length;
	        var ch = String(pCharPad).charAt(0);
	        for (; dif>0; dif--) str = ch + str;
	        return (str);
        } //String.lpad


        /**
         * Adiciona mtodo trim()  classe String.
         * Elimina brancos no incio e fim da String.
         */
        String.prototype.trim = function()
        {
	        return this.replace(/^\s*/, '').replace(/\s*$/, '');
        } //String.trim


        /**
         * Elimina caracteres de formatao e zeros  esquerda da string
         * de nmero fornecida.
         * @param String pNum
         *      String de nmero fornecida para ser desformatada.
         * @return String de nmero desformatada.
         */
        function unformatNumber(pNum)
        {
	        return String(pNum).replace(/\D/g, '').replace(/^0+/, '');
        } //unformatNumber


        /**
         * Formata a string fornecida como CNPJ ou CPF, adicionando zeros
         *  esquerda se necessrio e caracteres separadores, conforme solicitado.
         * @param String pCpfCnpj
         *      String fornecida para ser formatada.
         * @param boolean pUseSepar
         *      Indica se devem ser usados caracteres separadores (. - /).
         * @param boolean pIsCnpj
         *      Indica se a string fornecida  um CNPJ.
         *      Caso contrrio,  CPF. Default = false (CPF).
         * @return String de CPF ou CNPJ devidamente formatada.
         */
        function formatCpfCnpj(pCpfCnpj, pUseSepar, pIsCnpj)
        {
	        if (pIsCnpj==null) pIsCnpj = false;
	        if (pUseSepar==null) pUseSepar = true;
	        var maxDigitos = pIsCnpj? NUM_DIGITOS_CNPJ: NUM_DIGITOS_CPF;
	        var numero = unformatNumber(pCpfCnpj);

	        numero = numero.lpad(maxDigitos, '0');
	        if (!pUseSepar) return numero;

	        if (pIsCnpj)
	        {
		        reCnpj = /(\d{2})(\d{3})(\d{3})(\d{4})(\d{2})$/;
numero = numero.replace(reCnpj, '$1.$2.$3/$4-$5');
	        }
	        else
	        {
		        reCpf  = /(\d{3})(\d{3})(\d{3})(\d{2})$/;
		        numero = numero.replace(reCpf, '$1.$2.$3-$4');
	        }
	        return numero;
        } //formatCpfCnpj


        /**
         * Calcula os 2 dgitos verificadores para o nmero-efetivo pEfetivo de
         * CNPJ (12 dgitos) ou CPF (9 dgitos) fornecido. pIsCnpj  booleano e
         * informa se o nmero-efetivo fornecido  CNPJ (default = false).
         * @param String pEfetivo
         *      String do nmero-efetivo (SEM dgitos verificadores) de CNPJ ou CPF.
         * @param boolean pIsCnpj
         *      Indica se a string fornecida  de um CNPJ.
         *      Caso contrrio,  CPF. Default = false (CPF).
         * @return String com os dois dgitos verificadores.
         */
        function dvCpfCnpj(pEfetivo, pIsCnpj)
        {
	        if (pIsCnpj==null) pIsCnpj = false;
	        var i, j, k, soma, dv;
	        var cicloPeso = pIsCnpj? NUM_DGT_CNPJ_BASE: NUM_DIGITOS_CPF;
	        var maxDigitos = pIsCnpj? NUM_DIGITOS_CNPJ: NUM_DIGITOS_CPF;
	        var calculado = formatCpfCnpj(pEfetivo, false, pIsCnpj);
	        calculado = calculado.substring(2, maxDigitos);
	        var result = '';

	        for (j = 1; j <= 2; j++)
	        {
		        k = 2;
		        soma = 0;
		        for (i = calculado.length-1; i >= 0; i--)
		        {
			        soma += (calculado.charAt(i) - '0') * k;
			        k = (k-1) % cicloPeso + 2;
		        }
		        dv = 11 - soma % 11;
		        if (dv > 9) dv = 0;
		        calculado += dv;
		        result += dv
	        }

	        return result;
        } //dvCpfCnpj


        /**
         * Testa se a String pCpf fornecida  um CPF vlido.
         * Qualquer formatao que no seja algarismos  desconsiderada.
         * @param String pCpf
         *      String fornecida para ser testada.
         * @return <code>true</code> se a String fornecida for um CPF vlido.
         */
        function isCpf(pCpf)
        {
	        var numero = formatCpfCnpj(pCpf, false, false);
	        var base = numero.substring(0, numero.length - 2);
	        var digitos = dvCpfCnpj(base, false);
	        var algUnico, i;

	        // Valida dgitos verificadores
	        if (numero != base + digitos) return false;

	        /* No sero considerados vlidos os seguintes CPF:
	         * 000.000.000-00, 111.111.111-11, 222.222.222-22, 333.333.333-33, 444.444.444-44,
	         * 555.555.555-55, 666.666.666-66, 777.777.777-77, 888.888.888-88, 999.999.999-99.
	         */
	        algUnico = true;
	        for (i=1; i<NUM_DIGITOS_CPF; i++)
	        {
		        algUnico = algUnico && (numero.charAt(i-1) == numero.charAt(i));
	        }
	        return (!algUnico);
        } //isCpf


        /**
         * Testa se a String pCnpj fornecida  um CNPJ vlido.
         * Qualquer formatao que no seja algarismos  desconsiderada.
         * @param String pCnpj
         *      String fornecida para ser testada.
         * @return <code>true</code> se a String fornecida for um CNPJ vlido.
         */
        function isCnpj(pCnpj)
        {
	        var numero = formatCpfCnpj(pCnpj, false, true);
	        var base = numero.substring(0, NUM_DGT_CNPJ_BASE);
	        var ordem = numero.substring(NUM_DGT_CNPJ_BASE, 12);
	        var digitos = dvCpfCnpj(base + ordem, true);
	        var algUnico;

	        // Valida dgitos verificadores
	        if (numero != base + ordem + digitos) return false;

	        /* No sero considerados vlidos os CNPJ com os seguintes nmeros BSICOS:
	         * 11.111.111, 22.222.222, 33.333.333, 44.444.444, 55.555.555,
	         * 66.666.666, 77.777.777, 88.888.888, 99.999.999.
	         */
	        algUnico = numero.charAt(0) != '0';
	        for (i=1; i<NUM_DGT_CNPJ_BASE; i++)
	        {
		        algUnico = algUnico && (numero.charAt(i-1) == numero.charAt(i));
	        }
	        if (algUnico) return false;

	        /* No ser considerado vlido CNPJ com nmero de ORDEM igual a 0000.
	         * No ser considerado vlido CNPJ com nmero de ORDEM maior do que 0300
	         * e com as trs primeiras posies do nmero BSICO com 000 (zeros).
	         * Esta crtica no ser feita quando o no BSICO do CNPJ for igual a 00.000.000.
	         */
	        if (ordem == '0000') return false;
	        return (base == '00000000'
		        || parseInt(ordem, 10) <= 300 || base.substring(0, 3) != '000');
        }

        function valida ( source, arguments )
        {
            var numero = arguments.Value.replace(/\D/g, '');
            
            if (numero.length > NUM_DIGITOS_CPF)
                arguments.IsValid = isCnpj(arguments.Value);
            else 
                arguments.IsValid = isCpf(arguments.Value);
        }";
    }
    #endregion

    #region jsSelectCheckBox
    public static string jsSelectCheckBox()
    {
        return @"
        function SelectAllCheckboxes(spanChk)
        {
           // Added as ASPX uses SPAN for checkbox
            var oItem = spanChk.children;
            var theBox= (spanChk.type=='checkbox') ? 
                spanChk : spanChk.children.item[0];
            xState=theBox.checked;
            elm=theBox.form.elements;

            for(i=0;i<elm.length;i++)
             if(elm[i].type=='checkbox' && 
                      elm[i].id!=theBox.id && elm[i].id.split('_')[4]!='cbAllMan')
             {
                if(theBox.id.split('_')[4] == 'cbAllCon')
                {
                    if(elm[i].id.split('_')[6] != 'cbManGrid' )
                    {
                       if(elm[i].checked!=xState)
                         elm[i].checked=xState;
                    }
                }
                else
                {
                    if(elm[i].checked!=xState)
                        elm[i].checked=xState; 
                }
             }
        }";
    }
    #endregion

    #region jsCondicao100
    public static string jsCondicao100()
    {
        return @"
        function Condicao100 ( source, arguments )
        {
            var numero =  arguments.Value.replace(/\D/g, '');
            if (numero == '100,00' || numero == '100,0' || numero ==  '100')
            {
                arguments.IsValid = true;
            }
            else 
            {
                arguments.IsValid = false;
            }               
        }";
    }
    #endregion

    #region jsVazio
    public static string jsVazio()
    {
        return @"
        function Vazio ( source, arguments )
        {
            var numero = arguments.Value.replace(/\D/g, '');
            
            if (numero.length > 0)
                arguments.IsValid = true;
            else 
                arguments.IsValid = false;              
        }
        function Vazio4 ( source, arguments )
        {
            var numero = arguments.Value.replace(/\D/g, '');
            
            if (numero.length > 3)
                arguments.IsValid = true;
            else 
                arguments.IsValid = false;              
        }
        function Ano ( source, arguments )
        {
            var ano = arguments.Value;
            
            if (ano.length == 0 || ano > 1900 && ano <2101)
                arguments.IsValid = true;
            else 
                arguments.IsValid = false;              
        }
        function Condicao0 ( source, arguments )
        {
            var numero =  arguments.Value.replace(/\D/g, '');
            if (numero > 0)
            {
                arguments.IsValid = true;
            }
            else 
            {
                arguments.IsValid = false;
            }               
        }";
    }
    #endregion

    #region jsAbrirConta
    /// <summary>
    /// JS para abrir um PopUp com os detalhes da Conta
    /// Recebe um parmetro codConta
    /// </summary>
    /// <returns></returns>
    public static string jsAbrirConta(){
        //Abrir PopUpConta
        return @"
        var msg = null;

        function abrirConta(codConta) 
        {    
    	    if(msg)
    	        msg.close();
    	        url ='../Financeiro/PopupConta.aspx?codConta='+codConta;
		            msg=window.open(url,'msg','height=350,width=485,left=270,top=210');	
        }";
    }
    #endregion

    #region jCalendario
    /// <summary>
    /// js que monta e usa o Calendrio
    /// </summary>
    /// <returns>Calendrio</returns>
    public static string jsCalendario()
    {
        //Criar Calendrio
        // nessesrio que o ID do ImageButton (btiData) seja o mesmo ID do TextBox (txtData), mudandop apenas as trs primeiras letras
        //Adicionar no ImageButton (onclick="javascript:abreCalendario(this.id, event)")
        //Adicionar os seguintes scipts no 1 Pageload da pgina
        //<script type='text/javascript' language='javascript' src='../../Js/yahoo.js'></script>
        //<script type='text/javascript' language='javascript' src='../../Js/event.js' ></script>
        //<script type='text/javascript' language='javascript' src='../../Js/dom.js' ></script>
        //<script type='text/javascript' language='javascript' src='../../Js/calendar.js' ></script>"
        return @"
            /****************************************************************************************************/
	        YAHOO.namespace('example.calendar');
        	
	        function abreCalendario(campo, e){
		        idCampo = campo.replace('bti','txt');
		        posicionaCalendario(e);
		        updateCal(idCampo);
		        YAHOO.example.calendar.cal1.show();
	        }

	        function init() {
		        cal1Container = document.getElementById('cal1Container');
                var idCampo;
		        if(!eval(cal1Container)){
			        div = document.createElement('DIV')
			        div.id = 'cal1Container';
			        div.style.display = 'none';
			        div.style.zIndex = 99;
			        div.style.position = 'absolute';
			        document.body.appendChild(div);
		        }
        		
		        YAHOO.example.calendar.cal1 = new YAHOO.widget.Calendar('cal1','cal1Container', { title:'Escolha uma data:', close:true, LOCALE_WEEKDAYS:'1char' } );
		        YAHOO.example.calendar.cal1.render();
		        YAHOO.example.calendar.cal1.selectEvent.subscribe(handleSelect, YAHOO.example.calendar.cal1, true);

		        // Listener to show the 1-up Calendar when the button is clicked
		        //YAHOO.util.Event.addListener('btndate1', 'click', YAHOO.example.calendar.cal1.show, YAHOO.example.calendar.cal1, true);
	        }

	        YAHOO.util.Event.addListener(window, 'load', init);

	        /****************************************************************************************************/
	        function handleSelect(type,args,obj) {
		        var dates = args[0];
		        var date = dates[0];
		        var year = date[0], month = date[1], day = date[2];
        		
		        day 	= (day+100).toString().substring(1,3);
		        month 	= (month+100).toString().substring(1,3);

		        var txtDate1 = document.getElementById(idCampo);
		        txtDate1.value = day + '/' + month + '/' + year;
		        YAHOO.example.calendar.cal1.hide();
                document.getElementById(idCampo).focus();      		
	        }
	        /****************************************************************************************************/
        	
	        function updateCal(idCampo) {
		        var txtDate1 = document.getElementById(idCampo);
		        if(txtDate1.value != '' && txtDate1.value.length == 10){
			        dataUS = txtDate1.value.substring(3,6) + txtDate1.value.substring(0,3) + txtDate1.value.substring(6,10);
        	
			        // Select the date typed in the field
			        YAHOO.example.calendar.cal1.select(dataUS);
        	
			        var firstDate = YAHOO.example.calendar.cal1.getSelectedDates()[0];
        	
			        // Set the Calendar's page to the earliest selected date
			        YAHOO.example.calendar.cal1.cfg.setProperty('pagedate', (firstDate.getMonth()+1) + '/' + firstDate.getFullYear());
        	
			        YAHOO.example.calendar.cal1.render();
		        }
		        else{
			        YAHOO.example.calendar.cal1.select('');
			        txtDate1.value = '';
		        }
	        }
	        /****************************************************************************************************/			
        	
	        function posicionaCalendario(e){
		        posLeft = e.clientX - 150;
		        if(posLeft < 0)
		        posLeft = 5
		        document.getElementById('cal1Container').style.left = posLeft + 'px';
		        document.getElementById('cal1Container').style.top  = (e.clientY + 15) + 'px';
	        }
             
        ";
    }
    #endregion

    #region jsValidaData
    public static string jsValidaData()
    {
        return @"function validarData(campo){
            var expReg = /^(([0-2]\d|[3][0-1])\/([0]\d|[1][0-2])\/[1-2][0-9]\d{2})$/;
            var msgErro = 'Formato invlido de data.';
            if ((campo.value.match(expReg)) && (campo.value!='')){
                var dia = campo.value.substring(0,2);
                var mes = campo.value.substring(3,5);
                var ano = campo.value.substring(6,10);
                if(mes==04 || mes==06 || mes==09 || mes==11){
                    if( dia > 30){
                        alert('Dia incorreto !!! O ms especificado contm no mximo 30 dias.');
                    return false;
                    }
                } else{
                    if(ano%4!=0 && mes==02 && dia>28){
                        alert('Data incorreta!! O ms especificado contm no mximo 28 dias.');
                        return false;
                    } else{
                        if(ano%4==0 && mes==2 && dia>29){
                            alert('Data incorreta!! O ms especificado contm no mximo 29 dias.');
                        return false;
                        } else{                           
                            return true;
                        }
                    }
                }
            } else {
                if(campo.value != '__/__/____' && campo.value != '' ){
                    alert(msgErro);
                    campo.focus();
                }
            return false;
        }}";
    }
    #endregion

    #region jsComparaData
    /// <summary>
    /// Compara Duas Datas. CompareData('11/10/2008','12/11/2008') resultado = False, Ou seja a Data 2  maior que a Data 1
    /// dtaMenor, data que tem que ser menor, dataMaior Data que tem que ser Maior
    /// Ex: if(dtaMenor > dtaMaior) alert('Data Errada');
    /// </summary>
    /// <returns></returns>
    public static string jsComparaData()
    {
        //Se a primeira data (dtaMenor) for menor que a segunda data (dtaMaior) ento retorna True, caso contrrio, False.
        return @"function ComparaData(dtaMenor, dtaMaior)
                {
                    if(parseInt( dtaMenor.split( '/' )[2].toString() + dtaMenor.split( '/' )[1].toString() + dtaMenor.split( '/' )[0].toString() ) > parseInt( dtaMaior.split( '/' )[2].toString() + dtaMaior.split( '/' )[1].toString() + dtaMaior.split( '/' )[0].toString() ))
                        return true;
                    else 
                        return false;
                }";
    }
    #endregion

    #region jsMascaraMoeda
    /// <summary>
    /// JS script q cria formato moeda durante a digitao
    /// 
    /// parametros:    /// 
    /// objTextBox: o componente, (this)  este componente
    /// SeparadorMilesimo: (.)
    /// SeparadorDecimal: separa o inteiro dos decimos ex (,)
    /// e: evento de clic, traz o cod da tecla.
    /// TamanhaCompo: limite de digitos.
    /// Caracter: letras de prefixo ex. R$, %, AM, PM... 
    ///  onkeypress="return(MascaraMoeda(this,'.',',',event, 10, ''))" 
    /// </summary>
    /// <returns>digitos em formato moeda</returns>
    public static string jsMascaraMoeda()
    {
        return @"
   function MascaraMoeda(objTextBox, SeparadorMilesimo, SeparadorDecimal, e, TamanhaCompo, Caracter){
    var sep = 0;
    var key = '';
    var i = j = 0;
    var len = len2 = 0;
    var strCheck = '0123456789';
    var aux = aux2 = '';
    var whichCode = (window.Event) ? e.which : e.keyCode;
    if (whichCode == 13) return true;
    key = String.fromCharCode(whichCode); // Valor para o cdigo da Chave
    if (strCheck.indexOf(key) == -1) return false; // Chave invlida    
    
  var vaux = objTextBox.value.replace(Caracter,'').replace('.','');
  vaux=vaux.replace('.','');
  vaux=vaux.replace('.','');
  vaux=vaux.replace(',','');   

    if( vaux.length >= TamanhaCompo) 
        return;    
        
    objTextBox.value=objTextBox.value.replace(Caracter,'');
    len = objTextBox.value.length; 

    for(i = 0; i < len; i++)
        if ((objTextBox.value.charAt(i) != '0') && (objTextBox.value.charAt(i) != SeparadorDecimal)) break;
    aux = '';
    for(; i < len; i++)
        if (strCheck.indexOf(objTextBox.value.charAt(i))!=-1) aux += objTextBox.value.charAt(i);
    aux += key;
    len = aux.length;
    if (len == 0) objTextBox.value = Caracter;
    if (len == 1) objTextBox.value = Caracter+'0'+ SeparadorDecimal + '0' + aux;
    if (len == 2) objTextBox.value = Caracter+'0'+ SeparadorDecimal + aux;
    if (len > 2) {
        aux2 = '';
        for (j = 0, i = len - 3; i >= 0; i--) {
            if (j == 3) {
                aux2 += SeparadorMilesimo;
                j = 0;
            }
            aux2 += aux.charAt(i);
            j++;
        }

        objTextBox.value = Caracter;
        len2 = aux2.length; 

        for (i = len2 - 1; i >= 0; i--)
        objTextBox.value += aux2.charAt(i);
        objTextBox.value += SeparadorDecimal + aux.substr(len - 2, len);

    }

    return false;
    } ";
    }
    #endregion

    #region jsContaHoraMin
    /// <summary>
    /// JS script q cria e incrementa um contador na tela
    /// 
    /// parametros:    /// 
    /// na tela teve ter 3 objetos: enter, txtFim, tempo.
    /// document.all['enter']
    /// document.getElementById('ctl00$ContentPlaceHolder1$txtFim').value
    /// document.all['tempo'].innerHTML
    /// 
    /// </summary>
    /// <returns>Contador Hora Minuto Segundo</returns>
    public static string jsContaHoraMin()
    {
        return @"var segAntes;
            var segDepois;
            var minAntes;
            var minDepois;
            var horAntes;
            var horDepois;
            var tudoAntes; 
            var tudoDepois;
            var tudoTemp;
            var segTemp = -1;
            var minTemp = '0'+0;
            var horTemp = '0'+0;

            function comeca() {
                var hoje = new Date()
                segAntes = hoje.getSeconds()
                minAntes = hoje.getMinutes()
                horAntes = hoje.getHours()

                str_segAntes = new String (segAntes) 
                if (str_segAntes.length == 1) 
                   segAntes = '0' + segAntes 

                str_minAntes = new String (minAntes) 
                if (str_minAntes.length == 1) 
                   minAntes = '0' + minAntes 

                str_horAntes = new String (horAntes) 
                if (str_horAntes.length == 1) 
                   horAntes = '0' + horAntes
           
                tudoAntes = '' + horAntes + ':' + minAntes + ':' + segAntes + ''
                document.all['enter'].innerHTML=tudoAntes
            }

            function termina() {
                var ago = new Date()
                segDepois = ago.getSeconds()
                minDepois = ago.getMinutes()
                horDepois = ago.getHours()

                str_segDepois = new String (segDepois) 
                if (str_segDepois.length == 1) 
                   segDepois = '0' + segDepois 

                str_minDepois = new String (minDepois) 
                if (str_minDepois.length == 1) 
                   minDepois = '0' + minDepois 

                str_horDepois = new String (horDepois) 
                if (str_horDepois.length == 1) 
                   horDepois = '0' + horDepois

                tudoDepois = '' + horDepois + ':' + minDepois + ':' + segDepois + ''
                document.getElementById('ctl00$ContentPlaceHolder1$txtFim').value=tudoDepois //document.all['outUsr'].innerHTML=tudoDepois
            }

            function conta() {
	            segTemp++;
	            if(segTemp==60){
                    segTemp=0;minTemp++;
	                if(minTemp<=9)minTemp='0'+minTemp;
                }

	            if(minTemp==60){
                    minTemp='0'+0;horTemp++;
                    if(horTemp<=9)horTemp='0'+horTemp;
	            }
                if(segTemp<=9)segTemp='0'+segTemp;


                tudoTemp = '' + horTemp + ':' + minTemp + ':' + segTemp + ''
                document.all['tempo'].innerHTML=tudoTemp
            }

            function mostra() {
                alert(' Entrada: ' + tudoAntes + ' \n\     Saida: ' + tudoDepois + ' \n\   Tempo: ' + tudoTemp + '')
            }

            function atual(){
                termina()
                conta()
                setTimeout('atual()',1000)
            } ";
    }
    #endregion

    #region jsSoNumeros
    /// <summary>
    /// Rotina para aceitas apenas numeros em um TextBox.
    /// </summary>
    /// adicione no TextBox onkeypress="mascara(this,soNumeros)" onblur="mascara(this,soNumeros)"
    /// <returns></returns>
    public static string jsSoNumeros()
    {
        return @"function soNumeros(v){
                    return v.replace(/\D/g,'')
                }
                function mascara(o,f){
                    v_obj=o
                    v_fun=f
                    setTimeout('execmascara()',1)
                }
                function execmascara(){
                    v_obj.value=v_fun(v_obj.value)
                }";
    }
    #endregion

    #region jsFocus
    public static string jsFocus()
    {
        return @" 
            function Tabula(Next, QtdLimit, len, event){
                if(event.keyCode>=47 && event.keyCode<=106){
                    var x=len.replace('_','').replace('_',''); 
                    if(QtdLimit==x.length){
                        document.getElementById('ctl00_ContentPlaceHolder1_Tabs_Panel1_' + Next).focus();  
                        //$find('<%=Tabs.ClientID%>').focus();  
                    }   
                } 
                else
                    return null;     
            } 

            function TabulaTab2(Next, QtdLimit, len, event){
                if(event.keyCode>=47 && event.keyCode<=106){
                    var x=len.replace('_','').replace('_',''); 
                    if(QtdLimit==x.length){
                        document.getElementById('ctl00_ContentPlaceHolder1_Tabs_Panel2_' + Next).focus();  
                        //$find('<%=Tabs.ClientID%>').focus();  
                    }   
                } 
                else
                    return null;     
            } 
        ";
    }
    #endregion

    #region jsFocusAutoProximo
    public static string jsFocusAutoProximo()
    {
        return @"             
        function proximo(obj)
        {
            var elementos = document.getElementsByTagName('INPUT');
            for(var i=0;i<elementos.length;i++)
            {
                if(elementos[i].name==obj.name)
                {
                    while(elementos[i+1]!=null)
                    {
                        if(!elementos[i+1].disabled && elementos[i+1].tabIndex>=0)
                        {
                            elementos[i+1].focus();
                            return;
                        }
                        i++;
                    }
                }
            }
        }
        ";
    }
    #endregion

    #region jsAbrirPopup
    /// <summary>
    /// JS para abrir um PopUp
    /// Recebe dois parmetros 'url' e tamanho 'heigth= x, width y'
    /// </summary>
    /// <returns></returns>
    public static string jsAbrirPopup()
    {
        //Abrir PopUpConta
        return @"
        var msg = null;

        function abrirPopup(url,tamanho) 
        {    
    	    if(msg)
    	        msg.close();
		            msg=window.open(url,'msg',tamanho+',left=270,top=210');	
        }";
    }
    #endregion
}