using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using DcartesClassLibrary;

/// <summary>
/// User control de Valor Formato 999.999.999,00
/// Autor:  Jesiel Sopzak Campos
/// Data: 19/05/2008
/// </summary>

public partial class Sistema_UserControl_ucValor : System.Web.UI.UserControl
{
    #region Delegate
    public delegate void DelegateValor();
    #endregion

    #region Eventos
    public event DelegateValor SelValor;
    #endregion

    #region Propriedades

    #region Largura
    /// <summary>
    /// Width do Campo 
    /// </summary>
    public int Largura
    {
        get
        {
            return Convert.ToInt32(txtValor.Width.Value);
        }
        set
        {
            try
            {
                ViewState.Add("Width", Convert.ToInt32(value));
            }
            catch
            {
            }
        }
    }
    #endregion

    #region TxtValor
    /// <summary>
    /// Text Box do Campo
    /// </summary>
    public TextBox TxtValor
    {
        get
        {
            return txtValor;
        }
        set
        {
            try
            {
                txtValor = (TextBox)(value);
            }
            catch
            {
            }
        }
    }
    #endregion

    #region Valor
    /// <summary>
    /// Valor do Campo em Decimal
    /// </summary>
    public decimal Valor
    {
        get
        {
            if (txtValor.Text.Trim().Length > 0)
            {
                return Convert.ToDecimal(txtValor.Text);
            }
            return 0;
        }
        set
        {
            try
            {
                txtValor.Text = Convert.ToDecimal(value).ToString("N2");
            }
            catch
            {
            }
        }
    }
    #endregion

    #region UseDelete
    public bool UseDelete
    {
        get
        {
            if (ViewState["useDelete"] != null)
            {
                return Convert.ToBoolean(ViewState["useDelete"]);
            }
            else
            {
                return false;
            }
        }
        set
        {
            try
            {
                ViewState.Add("useDelete", value);
            }
            catch
            {
            }
        }
    }
    #endregion

    #region Obrigatorio
    public bool Obrigatorio
    {
        get
        {
            if (ViewState["Obrigatorio"] != null)
            {
                return Convert.ToBoolean(ViewState["Obrigatorio"]);
            }
            else
            {
                return false;
            }
        }
        set
        {
            try
            {
                ViewState.Add("Obrigatorio", value);
            }
            catch
            {
            }
        }
    }
    #endregion

    #region AutoPostBack
    public bool AutoPostBack
    {
        get
        {
            if (ViewState["autoPostBack"] != null)
            {
                return Convert.ToBoolean(ViewState["autoPostBack"]);
            }
            else
            {
                return false;
            }
        }
        set
        {
            try
            {
                ViewState.Add("autoPostBack", value);
            }
            catch
            {
            }
        }
    }
    #endregion

    #region MaxLength
    /// <summary>
    /// MaxLength do Campo 
    /// </summary>
    public int MaxLength
    {
        get
        {
            //retorna o maxlength
            return txtValor.MaxLength;
        }
        set
        {
            try
            {
                //seta o maxLength
                ViewState.Add("MaxLength", value);
            }
            catch
            {
            }
        }
    }
    #endregion

    #endregion

    #region Page_Load
    protected void Page_Load(object sender, EventArgs e)
    {
        Page.ClientScript.RegisterClientScriptBlock(
               this.GetType(),
               "Mascaras",
               JavaScriptMascaras.Mascaras(), true);
        Sistema_Template_TelaPadrao pgPadrao = new Sistema_Template_TelaPadrao();
        pgPadrao.DefinirMascara(txtValor, TipoMascara.VALOR);

        txtValor.Style.Value = "text-align:right";
        //seta o maxLength
        if (ViewState["MaxLength"] != null)
        {
            txtValor.MaxLength = Convert.ToInt32(ViewState["MaxLength"].ToString());
        }

        if (ViewState["Width"] != null)
        {
            int Width = Convert.ToInt32(ViewState["Width"]);
            txtValor.Attributes.CssStyle.Add("width", Width.ToString() + "px");
            Width += 20;
            div.Attributes.CssStyle.Add("width", Width.ToString() + "px");
        }

        if (!IsPostBack)
        {
            if (AutoPostBack)
            {
                txtValor.AutoPostBack = true;
            }
            else
            {
                txtValor.AutoPostBack = false;
            }
            if (Obrigatorio)
            {
                rfvValor.Enabled = true;
                rfvValor.Visible = true;
            }
            else
            {
                rfvValor.Enabled = false;
                rfvValor.Visible = false;
            }
        }
        Page.Validate();
    }
    #endregion

    #region txtValor_TextChanged
    protected void txtValor_TextChanged(object sender, EventArgs e)
    {
        if (UseDelete)
            SelValor();
    }
    #endregion
}
